#' h2 vector for 62 traits
#'
#' Example h2 vector used in the vignette and examples.
#'
#' @format A numeric matrix.
#' @source Internal simulation
"h2_vector"
